@@ -46,14 +46,6 @@ class GradeNotebooks():
                 with open(f"{zip_folder}/grading-logs.txt", "w") as f:
                     for line in stderr.decode().splitlines():
                         f.write(line  + "\n")
-                
-                for line in stderr.decode('utf-8').splitlines():
-                    if line.strip() == '':
-                        # Ignore empty lines
-                        continue
-                    if 'Killed' in line:
-                        # Our container was killed
-                        raise Exception(f"Container was killed -- nothing will work")
 
                 log.write_logs(f"Grading: Finished: {zip_folder}", "", "info", f'{os.environ.get("ENVIRONMENT")}-logs')
 
@@ -63,8 +55,54 @@ class GradeNotebooks():
             raise e  
         return "Grading Done"
 
+
+class BaseHandler(tornado.web.RequestHandler):
+    def get_current_user(self):
+        return self.get_secure_cookie("user")
+
+class GoogleOAuth2LoginHandler(tornado.web.RequestHandler,
+                               tornado.auth.GoogleOAuth2Mixin):
+    async def get(self):
+        if self.get_argument('code', False):
+            user = await self.get_authenticated_user(
+                redirect_uri='http://grader-dev.data8x.berkeley.edu',
+                code=self.get_argument('code'))
+            # Save the user with e.g. set_secure_cookie
+            self.set_secure_cookie("user", user)
+        else:
+            self.authorize_redirect(
+                redirect_uri='http://grader-dev.data8x.berkeley.edu',
+                client_id=self.settings['google_oauth']['key'],
+                scope=["profile","email"],
+                response_type='code',
+                extra_params={'approval_prompt': 'auto'})
+
+class LoginHandler(BaseHandler):
+    def get(self):
+        self.write('<html><body><form action="/login" method="post">'
+                   'Name: <input type="text" name="name">'
+                   'Password: <input type="password" name="password">'
+                   '<input type="submit" value="Sign in">'
+                   '</form></body></html>')
+
+    async def post(self):
+        # TODO: salt and hash the password before storing in the DB, then salt
+        # and hash the user's input password before comparing.
+        username = self.get_argument("name")
+        password = self.get_argument("password")
+
+        if password is not None:
+            self.set_secure_cookie("user", username)
+            self.redirect("/")
+        else:
+            # No such user or wrong password.
+            self.redirect("/login")
+
 class Userform(tornado.web.RequestHandler):
     def get(self):
+        if not self.current_user:
+            self.redirect("/login")
+            return
         self.render("index.html",  message=None)
 
 class Download(tornado.web.RequestHandler):
@@ -75,11 +113,11 @@ class Download(tornado.web.RequestHandler):
             msg = f"Please enter the download code to see your result."
             self.render("index.html",  download_message=msg)
         elif not os.path.exists(f"{directory}"):
-            msg = f"The download code appears to not be correct or expired - results are deleted each night: {code}. Please check the code or upload your notebooks and autograder.zip for grading again."
+            msg = f"The download code appears to not be correct or expired - results are deleted regularly: {code}. Please check the code or upload your notebooks and autograder.zip for grading again."
             self.render("index.html",  download_message=msg)
         elif not os.path.isfile(f"{directory}/final_grades.csv"):
-            msg = f"The results of your download are not ready yet. Please check back: {code}"
-            self.render("index.html",  download_message=msg)
+            msg = f"The results of your download are not ready yet. Please check back."
+            self.render("index.html",  download_message=msg, dcode=code)
         else:
             with ZipFile(f"{directory}/results.zip", 'w') as zipF:
                 for file in ["final_grades.csv","grading-output.txt","grading-logs.txt"]:
@@ -137,10 +175,13 @@ class Upload(tornado.web.RequestHandler):
             self.render("index.html", message=m)
         
 settings = {
-    "cookie_secret": str(uuid.uuid4())
+    "cookie_secret": str(uuid.uuid4()),
+    "google_oauth" : {"key": "263483406093-pg7m5o8tc9dfushpt5npe1bp1pnc9rr8.apps.googleusercontent.com"}
 }
 application = tornado.web.Application([
         (r"/", Userform),
+        (r"/glogin", LoginHandler),
+        (r"/login", GoogleOAuth2LoginHandler),
         (r"/upload", Upload),
         (r"/download", Download),
         ], **settings, debug=True)
